mock_main

package
v0.0.0-...-c71366f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 29, 2020 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package mock_main is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockDownloader

type MockDownloader struct {
	// contains filtered or unexported fields
}

MockDownloader is a mock of Downloader interface

func NewMockDownloader

func NewMockDownloader(ctrl *gomock.Controller) *MockDownloader

NewMockDownloader creates a new mock instance

func (*MockDownloader) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockDownloader) Get

func (m *MockDownloader) Get(url string) ([]byte, error)

Get mocks base method

type MockDownloaderMockRecorder

type MockDownloaderMockRecorder struct {
	// contains filtered or unexported fields
}

MockDownloaderMockRecorder is the mock recorder for MockDownloader

func (*MockDownloaderMockRecorder) Get

func (mr *MockDownloaderMockRecorder) Get(url interface{}) *gomock.Call

Get indicates an expected call of Get

type MockMenuCacher

type MockMenuCacher struct {
	// contains filtered or unexported fields
}

MockMenuCacher is a mock of MenuCacher interface

func NewMockMenuCacher

func NewMockMenuCacher(ctrl *gomock.Controller) *MockMenuCacher

NewMockMenuCacher creates a new mock instance

func (*MockMenuCacher) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockMenuCacher) GetMenu

func (m *MockMenuCacher) GetMenu(date time.Time) ([]*parser.Dish, error)

GetMenu mocks base method

func (*MockMenuCacher) Refresh

func (m *MockMenuCacher) Refresh() error

Refresh mocks base method

type MockMenuCacherMockRecorder

type MockMenuCacherMockRecorder struct {
	// contains filtered or unexported fields
}

MockMenuCacherMockRecorder is the mock recorder for MockMenuCacher

func (*MockMenuCacherMockRecorder) GetMenu

func (mr *MockMenuCacherMockRecorder) GetMenu(date interface{}) *gomock.Call

GetMenu indicates an expected call of GetMenu

func (*MockMenuCacherMockRecorder) Refresh

func (mr *MockMenuCacherMockRecorder) Refresh() *gomock.Call

Refresh indicates an expected call of Refresh

Jump to