Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OCRImage ¶
* OCRImage, passes the image contained in img to tesseract with "-l deu" and returns the text recognized by tesseract or an error
func UKSHMenuToTiles ¶
UKSHMenuToTiles, expects the bytes of png depicting the uksh menu plan and applies whaky 2D arithmetic to cut in into tiles containing the single dishes
Types ¶
type Dish ¶
type Dish struct {
Title string
Description string
Price string
Kcal string
Type string
Date time.Time
// contains filtered or unexported fields
}
func PDFToDishes ¶
mergeTextAndOCR, contains the information with textToDish with the price information from the OCR analysis
func PDFToDishesInYear ¶
mergeTextAndOCR, contains the information with textToDish with the price information from the OCR analysis
func TileToDish ¶
type UKSHParser ¶
type UKSHParser struct{}
func (*UKSHParser) PDFToDishes ¶
func (p *UKSHParser) PDFToDishes(pdf []byte) ([]*Dish, error)
type UKSHParserI ¶
Click to show internal directories.
Click to hide internal directories.